@@ -38,7 +38,7 @@ gnome_keyring_proto_set_uint32 (GString *buffer, gsize offset, guint32 val)
 		return FALSE;
 	}
 
-	ptr = buffer->str + offset;
+	ptr = (unsigned char *)buffer->str + offset;
 	ptr[0] = (val >> 24) & 0xff;
 	ptr[1] = (val >> 16) & 0xff;
 	ptr[2] = (val >> 8) & 0xff;
@@ -79,7 +79,7 @@ gnome_keyring_proto_get_uint32 (GString *buffer,
 		return FALSE;
 	}
 
-	ptr = buffer->str + offset;
+	ptr = (unsigned char *)buffer->str + offset;
 	if (val != NULL) {
 		*val = ptr[0] << 24 |
 			ptr[1] << 16 |
@@ -163,7 +163,7 @@ gboolean
 gnome_keyring_proto_get_bytes (GString *buffer,
 			       gsize offset,
 			       gsize *next_offset,
-			       char *out, gsize n_bytes)
+			       guchar *out, gsize n_bytes)
 {
 	if (buffer->len < n_bytes ||
 	    offset > buffer->len - n_bytes) {
@@ -588,6 +588,37 @@ gnome_keyring_proto_encode_set_attributes (GString                   *buffer,
 	return TRUE;
 }
 
+gboolean
+gnome_keyring_proto_encode_set_acl (GString                   *buffer,
+				    const char                *keyring,
+				    guint32                    id,
+				    GList                     *acl)
+{
+	gsize op_start;
+
+	if (!gnome_keyring_proto_start_operation (buffer,
+						  GNOME_KEYRING_OP_SET_ITEM_ACL,
+						  &op_start)) {
+		return FALSE;
+	}
+	if (!gnome_keyring_proto_add_utf8_string (buffer,
+						  keyring)) {
+		return FALSE;
+	}
+	gnome_keyring_proto_add_uint32 (buffer, id);
+	
+	if (!gnome_keyring_proto_add_acl (buffer, acl)) {
+		return FALSE;
+	}
+	
+	if (!gnome_keyring_proto_end_operation (buffer,	op_start)) {
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+
 gboolean
 gnome_keyring_proto_encode_set_item_info (GString                   *buffer,
 					  const char                *keyring,
@@ -629,8 +660,26 @@ gnome_keyring_proto_encode_set_keyring_info (GString                   *buffer,
 					     const char                *keyring,
 					     GnomeKeyringInfo          *info)
 {
-	/* TODO */
-	return FALSE;
+	gsize op_start;
+
+	if (!gnome_keyring_proto_start_operation (buffer,
+						  GNOME_KEYRING_OP_SET_KEYRING_INFO,
+						  &op_start)) {
+		return FALSE;
+	}
+	if (!gnome_keyring_proto_add_utf8_string (buffer,
+						  keyring)) {
+		return FALSE;
+	}
+	
+	gnome_keyring_proto_add_uint32 (buffer, info->lock_on_idle);
+	gnome_keyring_proto_add_uint32 (buffer, info->lock_timeout);
+
+	if (!gnome_keyring_proto_end_operation (buffer,	op_start)) {
+		return FALSE;
+	}
+
+	return TRUE;
 }
 
 
@@ -709,6 +758,67 @@ gnome_keyring_proto_decode_attribute_list (GString *buffer,
 	return FALSE;
 }
 
+gboolean
+gnome_keyring_proto_decode_acl (GString *buffer,
+				gsize offset, gsize *next_offset,
+				GList **acl_out)
+{
+	guint32 list_size;
+	GList *acl;
+	GnomeKeyringAccessControl *ac;
+	GnomeKeyringApplicationRef *ref;
+	char *display_name;
+	char *pathname;
+	guint32 types_allowed;
+	int i;
+
+	acl = NULL;
+
+	if (!gnome_keyring_proto_get_uint32 (buffer, offset, &offset, &list_size)) {
+		goto bail;
+	}
+
+	for (i = 0; i < list_size; i++) {
+		ac = g_new0 (GnomeKeyringAccessControl, 1);
+		ref = g_new0 (GnomeKeyringApplicationRef, 1);
+		if (!gnome_keyring_proto_get_utf8_string (buffer,
+							  offset, &offset,
+							  &display_name)) {
+			goto bail;
+		}
+		if (!gnome_keyring_proto_get_utf8_string (buffer,
+							  offset, &offset,
+							  &pathname)) {
+			g_free (display_name);
+			goto bail;
+		}
+
+		if (!gnome_keyring_proto_get_uint32 (buffer, offset, &offset, &types_allowed)) {
+			g_free (display_name);
+			g_free (pathname);
+			goto bail;
+		}
+		ref->display_name = display_name;
+		ref->pathname = pathname;
+		ac->application = ref;
+		ac->types_allowed = types_allowed;
+		acl = g_list_append (acl, ac);
+	}
+
+	if (acl_out != NULL) {
+		*acl_out = acl;
+	} else {
+		g_list_free (acl);
+	}
+	*next_offset = offset;
+	return TRUE;
+	
+ bail:
+	g_list_free (acl);
+	return FALSE;
+}
+
+
 gboolean
 gnome_keyring_proto_add_attribute_list (GString *buffer,
 					GnomeKeyringAttributeList *attributes)
@@ -745,6 +855,35 @@ gnome_keyring_proto_add_attribute_list (GString *buffer,
 	return TRUE;
 }
 
+gboolean
+gnome_keyring_proto_add_acl (GString *buffer,
+			     GList *acl)
+{
+	int length;
+	GnomeKeyringAccessControl *ac;
+	GList *tmp;
+
+	length = g_list_length (acl);
+
+	gnome_keyring_proto_add_uint32 (buffer, length);
+
+	for (tmp = acl; tmp != NULL; tmp = tmp->next) {
+		ac = (GnomeKeyringAccessControl *)tmp->data;
+		if (!gnome_keyring_proto_add_utf8_string (buffer,
+							  ac->application->display_name)) {
+			return FALSE;
+		}
+		if (!gnome_keyring_proto_add_utf8_string (buffer,
+							  ac->application->pathname)) {
+			return FALSE;
+		}
+		gnome_keyring_proto_add_uint32 (buffer, ac->types_allowed);
+	}
+
+	return TRUE;
+}
+
+
 
 gboolean
 gnome_keyring_proto_decode_result_reply (GString *buffer,
@@ -1040,6 +1179,33 @@ gnome_keyring_proto_decode_get_attributes_reply (GString                    *buf
 	return TRUE;
 }
 
+gboolean
+gnome_keyring_proto_decode_get_acl_reply (GString                    *buffer,
+					  GnomeKeyringResult         *result,
+					  GList                     **acl)
+{
+	gsize offset;
+	guint32 res;
+
+	offset = 4;
+	if (!gnome_keyring_proto_get_uint32 (buffer, offset, &offset, &res)) {
+		return FALSE;
+	}
+	*acl = NULL;
+	*result = res;
+	if (res == GNOME_KEYRING_RESULT_OK) {
+		if (!gnome_keyring_proto_decode_acl (buffer,
+						     offset, &offset,
+						     acl)) {
+			return FALSE;
+		}
+		
+	}
+		
+	return TRUE;
+}
+
+
 gboolean
 gnome_keyring_proto_decode_get_item_info_reply (GString                    *buffer,
 						GnomeKeyringResult         *result,
@@ -1210,6 +1376,47 @@ gnome_keyring_proto_decode_set_item_info (GString              *buffer,
 	return FALSE;
 }
 
+gboolean
+gnome_keyring_proto_decode_set_keyring_info (GString   *buffer,
+					     char     **keyring,
+					     gboolean  *lock_on_idle,
+					     guint32   *lock_timeout)
+
+{
+	gsize offset;
+	GnomeKeyringOpCode op;
+	guint32 lock_int;
+
+	*keyring = NULL;
+	
+	if (!gnome_keyring_proto_decode_packet_operation (buffer, &op)) {
+		return FALSE;
+	}
+	if (op != GNOME_KEYRING_OP_SET_KEYRING_INFO) {
+		return FALSE;
+	}
+	offset = 8;
+	if (!gnome_keyring_proto_get_utf8_string (buffer,
+						  offset, &offset,
+						  keyring)) {
+		goto bail;
+	}
+	if (!gnome_keyring_proto_get_uint32 (buffer, offset, &offset, &lock_int)) {
+		goto bail;
+	}
+	*lock_on_idle = lock_int;
+
+	if (!gnome_keyring_proto_get_uint32 (buffer, offset, &offset, lock_timeout)) {
+		goto bail;
+	}
+
+	return TRUE;
+	
+ bail:
+	g_free (*keyring);
+	return FALSE;
+}
+
 gboolean
 gnome_keyring_proto_decode_set_attributes (GString              *buffer,
 					   char                **keyring,
@@ -1252,6 +1459,48 @@ gnome_keyring_proto_decode_set_attributes (GString              *buffer,
 }
 
 
+gboolean
+gnome_keyring_proto_decode_set_acl (GString              *buffer,
+				    char                **keyring,
+				    guint32              *item_id,
+				    GList               **acl)
+{
+	gsize offset;
+	GnomeKeyringOpCode op;
+
+	*keyring = NULL;
+	*acl = NULL;
+	
+	if (!gnome_keyring_proto_decode_packet_operation (buffer, &op)) {
+		return FALSE;
+	}
+	if (op != GNOME_KEYRING_OP_SET_ITEM_ACL) {
+		return FALSE;
+	}
+	offset = 8;
+	if (!gnome_keyring_proto_get_utf8_string (buffer,
+						  offset, &offset,
+						  keyring)) {
+		goto bail;
+	}
+	if (!gnome_keyring_proto_get_uint32 (buffer, offset, &offset, item_id)) {
+		goto bail;
+	}
+	
+	if (!gnome_keyring_proto_decode_acl (buffer,
+					     offset, &offset,
+					     acl)) {
+		goto bail;
+	}
+
+	return TRUE;
+	
+ bail:
+	g_free (*keyring);
+	return FALSE;
+}
+
+
 
 gboolean
 gnome_keyring_proto_decode_result_int_list_reply (GString                    *buffer,
